/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |       (DATASET 0001: NTIES RESEARCH INTAKE QUESTIONNAIRE (NRIQ))
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 02884-0001-statasetup.do)
 |
 **************************************************************************/

set mem 20m  /* Allocating 20 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Treatment Improvement Evaluation Study (NTIES), 1992-1997, NTIES Research Intake Questionnaire (NRIQ)"

#delimit ;
label define R2        1 "SHORT TERM HOSPITAL" 2 "LONG TERM HOSPITAL"
                       3 "SHORT TERM RESIDENTIAL" 4 "LONG TERM RESIDENTIAL"
                       5 "OUTPATIENT METHADONE" 6 "AMBULATORY OUTPATIENT" ;
label define R5M1      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ON OR BEFORE MARCH 8, 1994"
                       2 "AFTER MARCH 8, 1994" ;
label define R15       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "ENGLISH" 1 "SPANISH" ;
label define PRGMTYPE  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CRITICAL POPULATIONS"
                       2 "CORRECTIONAL SETTINGS" 3 "OFFENDERS"
                       4 "TARGET CITIES" 5 "JUSTICE" 6 "PUBLIC HOUSING" ;
label define TRTMENT   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "HOSPITAL IN-PATIENT SHORT-TERM"
                       2 "HOSPITAL IN-PATIENT LONG-TERM"
                       3 "RESIDENTIAL SHORT-TERM" 4 "RESIDENTIAL LONG-TERM"
                       5 "OUT-PATIENT METHADONE" 6 "AMBULATORY OUT-PATIENT" ;
label define TRT2      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "SHORT-TERM RESIDENTIAL/IN-PATIENT"
                       2 "LONG-TERM RESIDENTIAL/IN-PATIENT"
                       3 "OUT-PATIENT METHADONE" 4 "AMBULATORY OUT-PATIENT" ;
label define PRG2      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "AJJ/ PH" 2 "CRIMINAL JUSTICE"
                       3 "TARGET CITIES" ;
label define CELL      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CP/ SR" 2 "CP/ LR" 3 "CP/ OP"
                       4 "TC/ SR" 5 "TC/ LR" 6 "TC/ OP" 7 "CJ/ SR" 8 "CJ/ LR"
                       9 "CJ/ OP" 10 "METHADONE" ;
label define CELL2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "METHADONE"
                       2 "NON-METHADONE OUT-PATIENT"
                       3 "SHORT-TERM RESIDENTIAL" 4 "LONG-TERM RESIDENTIAL"
                       5 "CORRECTIONAL SETTINGS" ;
label define R17       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "JAIL" 3 "PRISON" 4 "OTHER SITES" ;
label define R19       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R21       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "2 TO 6 DAYS" 3 "1-4 WEEKS"
                       4 "1-3 MONTHS" 5 "4-12 MONTHS" 6 "MORE THAN 1 YEAR" ;
label define R24M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M6     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M7     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "NO" ;
label define R24M8     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M9     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M10    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M11    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M12    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M13    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M14    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M15    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M16    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M17    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M18    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M19    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M21    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R24M22    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R25M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R25M2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R25M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R25M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R27       -9 "LEGITIMATE SKIP" ;
label define R29       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "MALE" 2 "FEMALE" ;
label define R34       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 17 "17 OR YOUNGER" 51 "51 OR OLDER" ;
label define R35       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" ;
label define R39       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R41       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R42       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R44M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONHISPANIC BLACK" 2 "HISPANIC"
                       3 "NONHISPANIC NONBLACK" ;
label define R46       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R47       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "SPANISH ONLY"
                       2 "OTHER LANGUAGE(S) ONLY"
                       3 "BOTH SPANISH AND OTHER LANGUAGE(S)" ;
label define R50       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ENGLISH" 2 "SPANISH"
                       3 "OTHER LANGUAGE(S)"
                       4 "PREFERENCE DEPENDS ON SITUATION" ;
label define R53       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "EXCELLENT?" 2 "GOOD?" 3 "FAIR?"
                       4 "POOR?" ;
label define R55       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M5     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M6     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M8     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R56M9     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R58       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 6 "6TH GRADE OR LOWER" 7 "7TH GRADE"
                       8 "8TH GRADE" 9 "9TH GRADE" 10 "10TH GRADE"
                       11 "11TH GRADE" 12 "12TH GRADE"
                       13 "1 YEAR COLLEGE/TECHNICAL SCHOOL"
                       14 "2 YEARS COLLEGE/TECHNICAL SCHOOL"
                       15 "3 YEARS COLLEGE/TECHNICAL SCHOOL"
                       16 "4 YEARS COLLEGE/TECHNICAL SCHOOL OR MORE" ;
label define R61       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R62       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "HIGH SCHOOL DIPLOMA"
                       2 "GED CERTIFICATE" ;
label define R64       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R67       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R71       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "BETTER THAN AVERAGE" 2 "AVERAGE"
                       3 "NOT SO GOOD" ;
label define R72       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R74       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R76       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 7 "7 OR YOUNGER" 8 "8" 9 "9" 10 "10"
                       11 "11" 12 "12" 13 "13" 14 "14" 15 "15" 16 "16"
                       17 "17" 18 "18 OR OLDER" ;
label define R77       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M5     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M6     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M7     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M8     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M10    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R84M12    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M1     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M2     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M3     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M4     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M5     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M6     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M7     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M8     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M9     -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M10    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R90M11    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R91       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH"
                       4 "R DOES NOT USE DRUGS OTHER THAN ALCOHOL" ;
label define R92       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" ;
label define R93       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 DAY OR LESS" 2 "2-6 DAYS"
                       3 "1-3 WEEKS" 4 "1-3 MONTHS" 5 "4-12 MONTHS"
                       6 "MORE THAN 1 YEAR" ;
label define R97       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R99       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R100M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R108A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R108A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES, DRUGS USED"
                       2 "NO, DRUGS NOT USED" ;
label define R113M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R113M14   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R114M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R116A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 9 "9 OR YOUNGER" 18 "18 OR OLDER" ;
label define R117A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 7 "7 OR YOUNGER" 21 "21 OR OLDER" ;
label define R117A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 14 "14 OR YOUNGER" 40 "40 OR OLDER" ;
label define R117A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R118A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R119A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN THE PAST MONTH"
                       2 "1-12 MONTHS AGO" 3 "MORE THAN 12 MONTHS AGO" ;
label define R120A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 12 "12 OR YOUNGER" 35 "35 OR OLDER" ;
label define R117A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R118A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R119A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN THE PAST MONTH"
                       2 "1-12 MONTHS AGO" 3 "MORE THAN 12 MONTHS AGO" ;
label define R120A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 13 "13 OR YOUNGER" 20 "20 OR OLDER" ;
label define R117A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 12 "12 OR YOUNGER" 22 "22 OR OLDER" ;
label define R117A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 13 "13 OR YOUNGER" 28 "28 OR OLDER" ;
label define R117A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "16 OR YOUNGER" 2 "17-20" 3 "21-25"
                       4 "26 OR OLDER" ;
label define R117A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 13 "13 OR YOUNGER" 22 "22 OR OLDER" ;
label define R117A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 12 "12 OR YOUNGER" 24 "24 OR OLDER" ;
label define R117A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 12 "12 OR YOUNGER" 22 "22 OR OLDER" ;
label define R117A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R123A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R116A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "16 OR YOUNGER" 2 "17-20" 3 "21-25"
                       4 "26 OR OLDER" ;
label define R117A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R120A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R122A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R124      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R125      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN THE PAST MONTH"
                       2 "1-12 MONTHS AGO" 3 "MORE THAN 12 MONTHS AGO" ;
label define R126      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE TIME" 2 "MORE THAN ONE TIME" ;
label define R127      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NOTHING" 1 "1-20" 2 "21-100"
                       3 "101-200" 4 "201-300" 5 "301-400" 6 "401-500"
                       7 "501-600" 8 "601-700" 9 "701-800" 10 "801-900"
                       11 "901-1000" 12 "1001-2000" 13 "2001-3000" 14 "5000" ;
label define R128      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R129      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "SKIP IF YES TO R128" ;
label define R130      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST 30 DAYS" 2 "AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R131      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE DAY" 2 "2-5 DAYS" 3 "6-10 DAYS"
                       4 "11-20 DAYS" 5 "21 DAYS OR MORE" ;
label define R132      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R133      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST 30 DAYS"
                       2 "31 DAYS AGO TO 12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R135      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN HALF OF THE TIME"
                       3 "HALF OF THE TIME" 4 "MORE THAN HALF OF THE TIME"
                       5 "EVERY TIME" ;
label define R136      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN HALF OF THE TIME"
                       3 "HALF OF THE TIME" 4 "MORE THAN HALF OF THE TIME"
                       5 "EVERY TIME" ;
label define R137      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN HALF OF THE TIME"
                       3 "HALF OF THE TIME" 4 "MORE THAN HALF OF THE TIME"
                       5 "EVERY TIME" ;
label define R138      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "ONE DAY" 3 "2-5 DAYS" 4 "6-10 DAYS"
                       5 "11-20 DAYS" 6 "21 DAYS OR MORE" ;
label define R139      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R140      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE DAY" 3 "2-5 DAYS"
                       4 "6-10 DAYS" 5 "11-20 DAYS" 6 "21 DAYS OR MORE" ;
label define R142A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE DAY" 3 "2-5 DAYS"
                       4 "6-10 DAYS" 5 "11-20 DAYS" 6 "21 DAYS OR MORE" ;
label define R143A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6"
                       9 "7-11" 12 "12" 18 "13-22" 24 "24" 40 "MORE THAN 25" ;
label define R144A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CANS" 2 "BOTTLES" 3 "GLASSES"
                       4 "QUARTS" 5 "PINTS" 10 "OTHER" ;
label define R147A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 8 "2-10" 12 "12" 16 "14-24" 40 "32-80" ;
label define R142A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE DAY" 3 "2-5 DAYS"
                       4 "6-10 DAYS" 5 "11-20 DAYS" 6 "21 DAYS OR MORE" ;
label define R143A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4" 8 "5 OR MORE" ;
label define R144A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 2 "BOTTLES" 3 "GLASSES" 6 "FIFTHS"
                       10 "OTHER" ;
label define R147A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 6 "1-8" 12 "9-15" 16 "16" 32 "20-64" ;
label define R142A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define R143A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4" 6 "5-10"
                       20 "11 OR MORE" ;
label define R144A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 4 "QUARTS" 5 "PINTS" 6 "FIFTHS"
                       7 "1/2 PINTS" 8 "SHOTS" 9 "DRINKS" 10 "OTHER" ;
label define R155      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE DAY" 3 "2-5 DAYS"
                       4 "6-10 DAYS" 5 "11-20 DAYS" 6 "21 DAYS OR MORE" ;
label define R156      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE TIME" 3 "2-5 TIMES"
                       4 "6-20 TIMES" 5 "21-100 TIMES"
                       6 "MORE THAN 100 TIMES" ;
label define R157      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R159      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R160      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R161      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define R162      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" ;
label define R171      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R172      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R173      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R174      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R175      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R176      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R177      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R178      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R179      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R182A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R184A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R184A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R184A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH"
                       2 "1 OR MORE MONTHS" ;
label define R182A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH"
                       2 "1 OR MORE MONTHS" ;
label define R182A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R182A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R185A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R187      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "RS OWN APARTMENT/HOUSE"
                       2 "SOMEONE ELSES APARTMENT/HOUSE"
                       3 "HOTEL,MOTEL,ROOMING/BOARDING HOUSE/DORM"
                       4 "HOMELESS SHELTER/ON STREET"
                       5 "OTHER TYPE OF SHELTER" 6 "HOSPITAL"
                       7 "DETENTION/ WORK RELEASE"
                       8 "OTHER TYPE OF GROUP HOME/TX CENTER"
                       9 "SOME OTHER PLACE" ;
label define R189      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R190      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" ;
label define R191      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define R192      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define R193      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R194      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R195      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 10 "10 OR MORE" ;
label define R198A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R198A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R198A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R198A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R198A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R200A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R202A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R200A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R202A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R200A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R202A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R200A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R202A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R200A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 MONTH" 2 "1-3 MONTHS"
                       3 "4-6 MONTHS" 4 "7-9 MONTHS" 5 "10-12 MONTHS" ;
label define R202A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R203      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R204M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R205      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R206M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R207      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R208M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R208M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R211      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R212      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R213      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R214      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R216      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4 OR MORE" ;
label define R218      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R219      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "R HAS CUSTODY OF ALL CHILDREN" ;
label define R220      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "R DOESNT HAVE CUSTODY OF ANY CHILDREN" ;
label define R221      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY EASY" 2 "SOMEWHAT EASY"
                       3 "SOMEWHAT DIFFICULT" 4 "VERY DIFFICULT"
                       5 "NEVER NEED TO GET CHILD CARE" ;
label define R222      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R223      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R225      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R226      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN ONE MONTH" 2 "1-12 MONTHS"
                       3 "MORE THAN 12 MONTHS" ;
label define R227      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4"
                       5 "5 OR MORE" ;
label define R228      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R229      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R231      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 41 "41 OR OLDER" 99 "NO ONE" ;
label define R232      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 41 "41 OR OLDER" 99 "NO ONE" ;
label define R233      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 41 "41 OR OLDER" 99 "NO ONE" ;
label define R234      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R236      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 5 "5 OR MORE" ;
label define R237      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R238      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4-9" 5 "10 OR MORE" ;
label define R239      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R240      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R241      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R242      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE TIME" 2 "2-5 TIMES" 3 "6-10 TIMES"
                       4 "11-20 TIMES" 5 "21-100 TIMES"
                       6 "MORE THAN 100 TIMES" ;
label define R244      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R245      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R246      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R247      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R248      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" 4 "NEVER RAISED CHILDREN" ;
label define R250      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" ;
label define R251      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY IMPORTANT" 2 "SOMEWHAT IMPORTANT"
                       3 "NOT AT ALL IMPORTANT" ;
label define R255      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R256      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R258      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5" 6 "6-9"
                       7 "10 OR MORE" ;
label define R259      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 15 "15 OR YOUNGER" 40 "40 OR OLDER"
                       999 "NO PRIOR TREATMENT" ;
label define R260      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 1 WEEK" 2 "1-2 WEEKS"
                       3 "3-4 WEEKS" 4 "1-6 MONTHS" 5 "7-12 MONTHS"
                       6 "MORE THAN 12 MONTHS" 7 "NO PRIOR TREATMENT" ;
label define R262      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "INPATIENT" 2 "RESIDENTIAL"
                       3 "OUTPATIENT" 4 "METHADONE" 5 "NO PRIOR TREATMENT" ;
label define R263      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R264      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ENTER PROVIDER" 2 "NONE MENTIONED"
                       3 "NO PRIOR TREATMENT" ;
label define R270M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NONE" 1 "1" 2 "2 OR MORE" ;
label define R270M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NONE" 1 "1" 2 "2 OR MORE" ;
label define R270M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NONE" 1 "1" 2 "2 OR MORE" ;
label define R270M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NONE" 1 "1" 2 "2 OR MORE" ;
label define R271      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R272M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R272M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R272M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R273      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "15 OR YOUNGER" 2 "16-20" 3 "21-25"
                       4 "26-30" 5 "31-35" 6 "36-40" 7 "41 OR OLDER" ;
label define R274      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R275      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R276      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "15 OR YOUNGER" 2 "16-20" 3 "21-25"
                       4 "26-30" 5 "31-35" 6 "36-40" 7 "41 OR OLDER" ;
label define R277      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4 OR MORE" ;
label define R278      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R279      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R280      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R281      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "1-5 TIMES" 3 "6-10 TIMES"
                       4 "11-30 TIMES" 5 "31 TIMES OR MORE" ;
label define R282      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R287      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R288      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R289      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" ;
label define R290      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R291      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R292      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R293      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R294      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R295      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R296      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "SKIPPED R295 YES" ;
label define R297      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" ;
label define R298      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R299      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R300      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R301      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO ATTEMPTS" ;
label define R302      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" 4 "NO ATTEMPTS" ;
label define R303      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R304      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" 4 "NO ATTEMPTS" ;
label define R305      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO"
                       3 "MADE ATTEMPTS (SEE R299)" ;
label define R306      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" ;
label define R307      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R308      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" ;
label define R309      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "SOME" 3 "ALL" ;
label define R310      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define R311      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL IMPORTANT"
                       2 "SOMEWHAT IMPORTANT" 3 "VERY IMPORTANT" ;
label define R313A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY EASY" 2 "SOMEWHAT EASY"
                       3 "SOMEWHAT DIFFICULT" 4 "VERY DIFFICULT" ;
label define R313A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY EASY" 2 "SOMEWHAT EASY"
                       3 "SOMEWHAT DIFFICULT" 4 "VERY DIFFICULT" ;
label define R313A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "VERY EASY" 2 "SOMEWHAT EASY"
                       3 "SOMEWHAT DIFFICULT" 4 "VERY DIFFICULT" ;
label define R322      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R323      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R324      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R325      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R326      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R327      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R328      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R329      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R330      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R331      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R332      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R333      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R334      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R335      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R336      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R337      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R338      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R339      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R340      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R341      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R344A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 11 "11 OR YOUNGER" 19 "19 OR OLDER" ;
label define R345A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R344A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 11 "11 OR YOUNGER" 30 "30 OR OLDER" ;
label define R345A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R345A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R345A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R344A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "11 OR YOUNGER" 2 "12-17"
                       3 "18 OR OLDER" ;
label define R345A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R344A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "11 OR YOUNGER" 2 "12-17"
                       3 "18 OR OLDER" ;
label define R345A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R344A15   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "11 OR YOUNGER" 2 "12-17"
                       3 "18 OR OLDER" ;
label define R345A15   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R345A16   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R345A17   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE" 2 "2-5" 3 "6-20" 4 "21-100"
                       5 "100+" 6 "NONE" ;
label define R344A18   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "11 OR YOUNGER" 2 "12-17"
                       3 "18 OR OLDER" ;
label define R346      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A14   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A14   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A15   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A15   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A16   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A16   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A17   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A17   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A18   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A18   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A19   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A19   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A20   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A20   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R348A21   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R351A21   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R352      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "15 OR YOUNGER" 2 "16-20" 3 "21-25"
                       4 "26 OR OLDER" ;
label define R353      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1-3 TIMES" 2 "4-10 TIMES"
                       3 "11 OR MORE TIMES" ;
label define R354      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 TIME" 2 "2-3 TIMES" 3 "4-10 TIMES"
                       4 "11 OR MORE TIMES" ;
label define R357      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R358      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R359      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 DAY OR LESS" 2 "2-6 DAYS"
                       3 "1-4 WEEKS" 4 "1-3 MONTHS" 5 "4-12 MONTHS"
                       6 "MORE THAN 1 YEAR" ;
label define R360      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R361      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "R 26 OR OLDER" ;
label define R362      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "R 26 OR OLDER" ;
label define R363      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R364      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R365      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R366      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R369      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "5 OR MORE TIMES PER WEEK"
                       2 "2-4 TIMES PER WEEK" 3 "ONCE A WEEK"
                       4 "2-3 TIMES A MONTH" 5 "ONCE A MONTH OR LESS"
                       6 "NOT UNDER SUPERVISION" ;
label define R371      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R372      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R373      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R377      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M12   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M13   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M14   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M15   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M16   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R378M17   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R379      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 11 "11 OR YOUNGER" 30 "30 OR OLDER" ;
label define R380      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R381      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R384A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 3 "SERVICE WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 14 "OTHER"
                       200 "NO CURRENT JOB" ;
label define R385A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R388A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1-20" 2 "21-35" 3 "36-45"
                       4 "46 OR MORE" ;
label define R389A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN ONE MONTH" 2 "1-12 MONTHS"
                       3 "MORE THAN 12 MONTHS" ;
label define R389A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN ONE MONTH" 2 "1-12 MONTHS"
                       3 "MORE THAN 12 MONTHS" ;
label define R391      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R392      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO CURRENT JOB" ;
label define R393      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO CURRENT JOB" ;
label define R397M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R397M11   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "CURRENTLY EMPLOYED F/T" ;
label define R399      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN THE PAST MONTH"
                       2 "1-6 MONTHS AGO" 3 "7-12 MONTHS AGO"
                       4 "MORE THAN 12 MONTHS AGO" 5 "CURRENTLY WORKING" ;
label define R400      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN ONE MONTH" 2 "1-6 MONTHS"
                       3 "7-12 MONTHS" 4 "MORE THAN 12 MONTHS" ;
label define R401      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R403      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CLERICAL WORKER" 2 "SALES WORKER"
                       3 "SERVICE WORKER" 4 "PRIVATE HOUSEHOLD WORKER"
                       5 "SKILLED WORKER OR CRAFTSMEN" 6 "LABORER"
                       7 "OPERATOR OR MACHINE OPERATOR"
                       8 "TRANSPORTATION EQUIPMENT OPERATOR" 9 "FARM LABORER"
                       10 "FARMER OR FARM MANAGER"
                       11 "MANAGER/ ADMINISTRATOR" 12 "LAY COUNSELOR"
                       13 "PROFESSIONAL/ TECHNICAL" 14 "OTHER"
                       15 "INTERVIEWER UNABLE TO CODE" ;
label define R407M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN 4.25 PER HOUR"
                       2 "4.25-10.00 PER HOUR" 3 "MORE THAN $10.00 PER HOUR" ;
label define R409      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "LESS THAN ONE MONTH"
                       3 "1-3 MONTHS" 4 "4-6 MONTHS" 5 "7-9 MONTHS"
                       6 "10-12 MONTHS" ;
label define R411      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL IMPORTANT"
                       2 "SOMEWHAT IMPORTANT" 3 "VERY IMPORTANT" ;
label define R412      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R413      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "LESS THAN HALF" 2 "HALF OR MORE"
                       3 "ALL" ;
label define R416A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R416A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R419M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "Male, $3000 or less"
                       2 "Male, 3001-$10000" 3 "Male, $10001 or more"
                       4 "Female, $3000 or less" 5 "Female, $3001 or more" ;
label define R419M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "Male, $3000 or less"
                       2 "Male, $3001-$10000" 3 "Male, $10001 or more"
                       4 "Female, $3000 or less" 5 "Female, $3001 or more" ;
label define R420      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL IMPORTANT"
                       2 "SOMEWHAT IMPORTANT" 3 "VERY IMPORTANT" ;
label define R423      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "EXCELLENT?" 2 "GOOD?" 3 "FAIR?"
                       4 "POOR?" ;
label define R427A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A6    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A7    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A8    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A9    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R427A10   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R428      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R429      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R431      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL" 2 "SOMEWHAT" 3 "VERY MUCH" ;
label define R436A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-9" 4 "10-25"
                       5 "26-100" 6 "101-500" 7 "MORE THAN 500" ;
label define R437A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN 1/2"
                       3 "HALF OF THE TIME" 4 "MORE THAN 1/2" 5 "EVERY TIME"
                       6 "NO SUCH PARTNERS" ;
label define R436A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-9" 4 "10-25"
                       5 "26-100" 6 "101-500" 7 "MORE THAN 500" ;
label define R437A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN 1/2"
                       3 "HALF OF THE TIME" 4 "MORE THAN 1/2" 5 "EVERY TIME"
                       6 "NO SUCH PARTNERS" ;
label define R436A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR MORE" ;
label define R437A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN 1/2"
                       3 "HALF OF THE TIME" 4 "MORE THAN 1/2" 5 "EVERY TIME"
                       6 "NO SUCH PARTNERS" ;
label define R436A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE OR MORE" ;
label define R437A4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN 1/2"
                       3 "HALF OF THE TIME" 4 "MORE THAN 1/2" 5 "EVERY TIME"
                       6 "NO SUCH PARTNERS" ;
label define R436A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "ONE" 3 "2-9" 4 "10-25"
                       5 "26-100" ;
label define R437A5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NEVER" 2 "LESS THAN 1/2"
                       3 "HALF OF THE TIME" 4 "MORE THAN 1/2" 5 "EVERY TIME"
                       6 "NO SUCH PARTNERS" ;
label define R439      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R440      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R441      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R442      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R443      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R444      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R445      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE TIME" 2 "2-5 TIMES" 3 "6-10 TIMES"
                       4 "11-20 TIMES" 5 "21-100 TIMES"
                       6 "MORE THAN 100 TIMES" ;
label define R447      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R448      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "ONE TIME" 2 "2-5 TIMES" 3 "6-10 TIMES"
                       4 "11-20 TIMES" 5 "21-100 TIMES"
                       6 "MORE THAN 100 TIMES" ;
label define R449      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R450      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R451      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R452      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R454A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 TIME" 2 "2-5 TIMES" 3 "6-9 TIMES"
                       4 "10 OR MORE TIMES" ;
label define R456A1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R455A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 TIME" 2 "2-9 TIMES"
                       3 "10 TIMES OR MORE" ;
label define R456A2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R455A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1 TIME" 2 "2-9 TIMES"
                       3 "10 TIMES OR MORE" ;
label define R456A3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R457      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NOT AT ALL IMPORTANT"
                       2 "SOMEWHAT IMPORTANT" 3 "VERY IMPORTANT" ;
label define R458      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R459M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R459M2    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R459M3    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R459M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R462M1    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R462M4    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R462M5    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R463      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE (MALE)"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R464      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE (MALE)"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5"
                       6 "6 OR MORE" ;
label define R465      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NONE" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5"
                       6 "6 OR MORE" ;
label define R466      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "WITHIN PAST MONTH" 2 "1-12 MONTHS AGO"
                       3 "MORE THAN 12 MONTHS AGO" ;
label define R467      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE (MALE)"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO BIRTHS" ;
label define R468      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE (MALE)"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" 3 "NO BIRTHS" ;
label define R469      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "HIV?" 2 "FOR HIV?" 3 "NO BIRTHS" ;
label define R470      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE (MALE)"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define R471      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "INCREASED" 2 "STAYED ABOUT THE SAME"
                       3 "DECREASED" ;
label define R472      -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "YES" 2 "NO" ;
label define RTOTANS   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define RTOTREF   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define RTOTDK    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define AFDRUG1   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "COCAINE" 2 "HEROIN" 3 "ALCOHOL"
                       4 "MARIJUANA" 5 "OTHER" ;
label define AFDRUG2   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "COCAINE" 2 "HEROIN" 3 "ALCOHOL"
                       4 "MARIJUANA" 5 "OTHER" ;
label define QUEXSTAT  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NONE" 2 "NTEQ ONLY" 3 "NTEQ & NPAQ"
                       4 "NTEQ, NPAQ, & NPRAF" 5 "NTEQ & NPRAF" 6 "NPAQ ONLY"
                       7 "NPAQ AND NPRAF" 8 "NPRAF ONLY" ;
label define BCSTAT    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NBAR & NCAR" 2 "NBAR ONLY"
                       4 "NO NBAR/ NCAR" ;
label define URISTAT   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "NO NPAQ" 2 "NOT ASKED"
                       3 "ASKED, URINE NA" 4 "GOOD DATA" ;
label define LOSCENSR  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NOT CENSORED" 1 "MIN LOS" 2 "MAX LOS"
                       3 "ESTIMATED LOS" 4 "MISSING LOS" ;
label define DURATTX   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define DURAPTX   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define DURAPDP   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define TFSCOMP   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "STILL IN TX" 2 "TX COMPLETED"
                       3 "TX NOT COMPLETED" 4 "INCONSISTENT DATA" ;
label define NRIQLTAR  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CONCORDANT" 2 "SELF RPT>STATE RPT"
                       3 "STATE RPT>SELF RPT" ;
label define NRIQDRUG  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CONCORDANT" 2 "SELF RPT>STATE RPT"
                       3 "STATE RPT>SELF RPT" ;
label define NPAQAR    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 1 "CONCORDANT" 2 "SELF RPT>STATE RPT"
                       3 "STATE RPT>SELF RPT" ;
label define FLDISP    -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 10 "NO PROBLEM WITH SAMPLE"
                       20 "URINE WAS COLD" 40 "SUSPECT ADULTERATION"
                       50 "OTHER" 79 "CONDITION MISSING" ;
label define LABDISP   -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 11 "SAMPLE SEEMS OK"
                       12 "SAMPLE SEEMS ADULTERATED" 13 "INSUFFICIENT SAMPLE"
                       14 "SAMPLE CONDITION MISSING" ;
label define CAN       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define COC       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define PCP       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define OPI       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define AMP       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define BEN       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define MET       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define ALC       -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" 0 "NEGATIVE" 1 "POSITIVE" ;
label define RBEERVOL  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define RWINEVOL  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;
label define RLIQUVOL  -9 "LEGITIMATE SKIP" -8 "NOT ASKED OF MINORS"
                       -7 "NOT ASKED OF INMATES" -6 "NOT APPLICABLE"
                       -5 "NEVER" -4 "NONE" -3 "MISSING" -2 "DON'T KNOW"
                       -1 "REFUSAL" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace R2 = . if (R2 <= -1 )
replace R5M1 = . if (R5M1 <= -1 )
replace R15 = . if (R15 <= -1 )
replace PRGMTYPE = . if (PRGMTYPE <= -1 )
replace TRTMENT = . if (TRTMENT <= -1 )
replace TRT2 = . if (TRT2 <= -1 )
replace PRG2 = . if (PRG2 <= -1 )
replace CELL = . if (CELL <= -1 )
replace CELL2 = . if (CELL2 <= -1 )
replace R17 = . if (R17 <= -1 )
replace R19 = . if (R19 <= -1 )
replace R21 = . if (R21 <= -1 )
replace R24M1 = . if (R24M1 <= -1 )
replace R24M2 = . if (R24M2 <= -1 )
replace R24M3 = . if (R24M3 <= -1 )
replace R24M4 = . if (R24M4 <= -1 )
replace R24M6 = . if (R24M6 <= -1 )
replace R24M7 = . if (R24M7 <= -1 )
replace R24M8 = . if (R24M8 <= -1 )
replace R24M9 = . if (R24M9 <= -1 )
replace R24M10 = . if (R24M10 <= -1 )
replace R24M11 = . if (R24M11 <= -1 )
replace R24M12 = . if (R24M12 <= -1 )
replace R24M13 = . if (R24M13 <= -1 )
replace R24M14 = . if (R24M14 <= -1 )
replace R24M15 = . if (R24M15 <= -1 )
replace R24M16 = . if (R24M16 <= -1 )
replace R24M17 = . if (R24M17 <= -1 )
replace R24M18 = . if (R24M18 <= -1 )
replace R24M19 = . if (R24M19 <= -1 )
replace R24M21 = . if (R24M21 <= -1 )
replace R24M22 = . if (R24M22 <= -1 )
replace R25M1 = . if (R25M1 <= -1 )
replace R25M2 = . if (R25M2 <= -1 )
replace R25M3 = . if (R25M3 <= -1 )
replace R25M4 = . if (R25M4 <= -1 )
replace R27 = . if (R27 <= -1 )
replace R29 = . if (R29 <= -1 )
replace R34 = . if (R34 <= -1 )
replace R35 = . if (R35 <= -1 )
replace R39 = . if (R39 <= -1 )
replace R41 = . if (R41 <= -1 )
replace R42 = . if (R42 <= -1 )
replace R44M1 = . if (R44M1 <= -1 )
replace R46 = . if (R46 <= -1 )
replace R47 = . if (R47 <= -1 )
replace R50 = . if (R50 <= -1 )
replace R53 = . if (R53 <= -1 )
replace R55 = . if (R55 <= -1 )
replace R56M1 = . if (R56M1 <= -1 )
replace R56M2 = . if (R56M2 <= -1 )
replace R56M3 = . if (R56M3 <= -1 )
replace R56M4 = . if (R56M4 <= -1 )
replace R56M5 = . if (R56M5 <= -1 )
replace R56M6 = . if (R56M6 <= -1 )
replace R56M8 = . if (R56M8 <= -1 )
replace R56M9 = . if (R56M9 <= -1 )
replace R58 = . if (R58 <= -1 )
replace R61 = . if (R61 <= -1 )
replace R62 = . if (R62 <= -1 )
replace R64 = . if (R64 <= -1 )
replace R67 = . if (R67 <= -1 )
replace R71 = . if (R71 <= -1 )
replace R72 = . if (R72 <= -1 )
replace R74 = . if (R74 <= -1 )
replace R76 = . if (R76 <= -1 )
replace R77 = . if (R77 <= -1 )
replace R79 = . if (R79 <= -1 )
replace R84M1 = . if (R84M1 <= -1 )
replace R84M2 = . if (R84M2 <= -1 )
replace R84M3 = . if (R84M3 <= -1 )
replace R84M4 = . if (R84M4 <= -1 )
replace R84M5 = . if (R84M5 <= -1 )
replace R84M6 = . if (R84M6 <= -1 )
replace R84M7 = . if (R84M7 <= -1 )
replace R84M8 = . if (R84M8 <= -1 )
replace R84M10 = . if (R84M10 <= -1 )
replace R84M12 = . if (R84M12 <= -1 )
replace R90M1 = . if (R90M1 <= -1 )
replace R90M2 = . if (R90M2 <= -1 )
replace R90M3 = . if (R90M3 <= -1 )
replace R90M4 = . if (R90M4 <= -1 )
replace R90M5 = . if (R90M5 <= -1 )
replace R90M6 = . if (R90M6 <= -1 )
replace R90M7 = . if (R90M7 <= -1 )
replace R90M8 = . if (R90M8 <= -1 )
replace R90M9 = . if (R90M9 <= -1 )
replace R90M10 = . if (R90M10 <= -1 )
replace R90M11 = . if (R90M11 <= -1 )
replace R91 = . if (R91 == 4)
replace R91 = . if (R91 <= -1 )
replace R92 = . if (R92 <= -1 )
replace R93 = . if (R93 <= -1 )
replace R97 = . if (R97 <= -1 )
replace R99 = . if (R99 <= -1 )
replace R100M1 = . if (R100M1 <= -1 )
replace R100M2 = . if (R100M2 <= -1 )
replace R100M3 = . if (R100M3 <= -1 )
replace R100M4 = . if (R100M4 <= -1 )
replace R100M5 = . if (R100M5 <= -1 )
replace R100M6 = . if (R100M6 <= -1 )
replace R102 = . if (R102 <= -1 )
replace R108A1 = . if (R108A1 <= -1 )
replace R108A2 = . if (R108A2 <= -1 )
replace R108A3 = . if (R108A3 <= -1 )
replace R108A4 = . if (R108A4 <= -1 )
replace R108A5 = . if (R108A5 <= -1 )
replace R108A6 = . if (R108A6 <= -1 )
replace R108A7 = . if (R108A7 <= -1 )
replace R108A8 = . if (R108A8 <= -1 )
replace R108A9 = . if (R108A9 <= -1 )
replace R108A10 = . if (R108A10 <= -1 )
replace R108A11 = . if (R108A11 <= -1 )
replace R108A12 = . if (R108A12 <= -1 )
replace R113M1 = . if (R113M1 <= -1 )
replace R113M2 = . if (R113M2 <= -1 )
replace R113M3 = . if (R113M3 <= -1 )
replace R113M4 = . if (R113M4 <= -1 )
replace R113M5 = . if (R113M5 <= -1 )
replace R113M6 = . if (R113M6 <= -1 )
replace R113M7 = . if (R113M7 <= -1 )
replace R113M8 = . if (R113M8 <= -1 )
replace R113M9 = . if (R113M9 <= -1 )
replace R113M10 = . if (R113M10 <= -1 )
replace R113M11 = . if (R113M11 <= -1 )
replace R113M12 = . if (R113M12 <= -1 )
replace R113M13 = . if (R113M13 <= -1 )
replace R113M14 = . if (R113M14 <= -1 )
replace R114M1 = . if (R114M1 <= -1 )
replace R114M2 = . if (R114M2 <= -1 )
replace R114M3 = . if (R114M3 <= -1 )
replace R114M4 = . if (R114M4 <= -1 )
replace R114M5 = . if (R114M5 <= -1 )
replace R114M6 = . if (R114M6 <= -1 )
replace R114M7 = . if (R114M7 <= -1 )
replace R114M8 = . if (R114M8 <= -1 )
replace R116A1 = . if (R116A1 <= -1 )
replace R117A1 = . if (R117A1 <= -1 )
replace R120A1 = . if (R120A1 <= -1 )
replace R122A1 = . if (R122A1 <= -1 )
replace R116A2 = . if (R116A2 <= -1 )
replace R117A2 = . if (R117A2 <= -1 )
replace R120A2 = . if (R120A2 <= -1 )
replace R122A2 = . if (R122A2 <= -1 )
replace R123A2 = . if (R123A2 <= -1 )
replace R116A3 = . if (R116A3 <= -1 )
replace R117A3 = . if (R117A3 <= -1 )
replace R118A3 = . if (R118A3 <= -1 )
replace R119A3 = . if (R119A3 <= -1 )
replace R120A3 = . if (R120A3 <= -1 )
replace R122A3 = . if (R122A3 <= -1 )
replace R123A3 = . if (R123A3 <= -1 )
replace R116A4 = . if (R116A4 <= -1 )
replace R117A4 = . if (R117A4 <= -1 )
replace R118A4 = . if (R118A4 <= -1 )
replace R119A4 = . if (R119A4 <= -1 )
replace R120A4 = . if (R120A4 <= -1 )
replace R122A4 = . if (R122A4 <= -1 )
replace R123A4 = . if (R123A4 <= -1 )
replace R116A5 = . if (R116A5 <= -1 )
replace R117A5 = . if (R117A5 <= -1 )
replace R120A5 = . if (R120A5 <= -1 )
replace R122A5 = . if (R122A5 <= -1 )
replace R116A6 = . if (R116A6 <= -1 )
replace R117A6 = . if (R117A6 <= -1 )
replace R120A6 = . if (R120A6 <= -1 )
replace R122A6 = . if (R122A6 <= -1 )
replace R116A7 = . if (R116A7 <= -1 )
replace R117A7 = . if (R117A7 <= -1 )
replace R120A7 = . if (R120A7 <= -1 )
replace R122A7 = . if (R122A7 <= -1 )
replace R123A7 = . if (R123A7 <= -1 )
replace R116A8 = . if (R116A8 <= -1 )
replace R117A8 = . if (R117A8 <= -1 )
replace R120A8 = . if (R120A8 <= -1 )
replace R122A8 = . if (R122A8 <= -1 )
replace R116A9 = . if (R116A9 <= -1 )
replace R117A9 = . if (R117A9 <= -1 )
replace R120A9 = . if (R120A9 <= -1 )
replace R122A9 = . if (R122A9 <= -1 )
replace R123A9 = . if (R123A9 <= -1 )
replace R116A10 = . if (R116A10 <= -1 )
replace R117A10 = . if (R117A10 <= -1 )
replace R120A10 = . if (R120A10 <= -1 )
replace R122A10 = . if (R122A10 <= -1 )
replace R123A10 = . if (R123A10 <= -1 )
replace R116A11 = . if (R116A11 <= -1 )
replace R117A11 = . if (R117A11 <= -1 )
replace R120A11 = . if (R120A11 <= -1 )
replace R122A11 = . if (R122A11 <= -1 )
replace R123A11 = . if (R123A11 <= -1 )
replace R116A12 = . if (R116A12 <= -1 )
replace R117A12 = . if (R117A12 <= -1 )
replace R120A12 = . if (R120A12 <= -1 )
replace R122A12 = . if (R122A12 <= -1 )
replace R124 = . if (R124 <= -1 )
replace R125 = . if (R125 <= -1 )
replace R126 = . if (R126 <= -1 )
replace R127 = . if (R127 <= -1 )
replace R128 = . if (R128 <= -1 )
replace R129 = . if (R129 == 3)
replace R129 = . if (R129 <= -1 )
replace R130 = . if (R130 <= -1 )
replace R131 = . if (R131 <= -1 )
replace R132 = . if (R132 <= -1 )
replace R133 = . if (R133 <= -1 )
replace R135 = . if (R135 <= -1 )
replace R136 = . if (R136 <= -1 )
replace R137 = . if (R137 <= -1 )
replace R138 = . if (R138 <= -1 )
replace R139 = . if (R139 <= -1 )
replace R140 = . if (R140 <= -1 )
replace R142A1 = . if (R142A1 <= -1 )
replace R143A1 = . if (R143A1 <= -1 )
replace R144A1 = . if (R144A1 <= -1 )
replace R147A1 = . if (R147A1 <= -1 )
replace R142A2 = . if (R142A2 <= -1 )
replace R143A2 = . if (R143A2 <= -1 )
replace R144A2 = . if (R144A2 <= -1 )
replace R147A2 = . if (R147A2 <= -1 )
replace R142A3 = . if (R142A3 <= -1 )
replace R143A3 = . if (R143A3 <= -1 )
replace R144A3 = . if (R144A3 <= -1 )
replace R155 = . if (R155 <= -1 )
replace R156 = . if (R156 <= -1 )
replace R157 = . if (R157 <= -1 )
replace R159 = . if (R159 <= -1 )
replace R160 = . if (R160 <= -1 )
replace R161 = . if (R161 <= -1 )
replace R162 = . if (R162 <= -1 )
replace R171 = . if (R171 <= -1 )
replace R172 = . if (R172 <= -1 )
replace R173 = . if (R173 <= -1 )
replace R174 = . if (R174 <= -1 )
replace R175 = . if (R175 <= -1 )
replace R176 = . if (R176 <= -1 )
replace R177 = . if (R177 <= -1 )
replace R178 = . if (R178 <= -1 )
replace R179 = . if (R179 <= -1 )
replace R182A1 = . if (R182A1 <= -1 )
replace R184A1 = . if (R184A1 <= -1 )
replace R185A1 = . if (R185A1 <= -1 )
replace R182A2 = . if (R182A2 <= -1 )
replace R184A2 = . if (R184A2 <= -1 )
replace R185A2 = . if (R185A2 <= -1 )
replace R182A3 = . if (R182A3 <= -1 )
replace R184A3 = . if (R184A3 <= -1 )
replace R185A3 = . if (R185A3 <= -1 )
replace R182A4 = . if (R182A4 <= -1 )
replace R185A4 = . if (R185A4 <= -1 )
replace R182A5 = . if (R182A5 <= -1 )
replace R185A5 = . if (R185A5 <= -1 )
replace R182A6 = . if (R182A6 <= -1 )
replace R185A6 = . if (R185A6 <= -1 )
replace R182A7 = . if (R182A7 <= -1 )
replace R185A7 = . if (R185A7 <= -1 )
replace R182A8 = . if (R182A8 <= -1 )
replace R185A8 = . if (R185A8 <= -1 )
replace R182A9 = . if (R182A9 <= -1 )
replace R185A9 = . if (R185A9 <= -1 )
replace R187 = . if (R187 <= -1 )
replace R189 = . if (R189 <= -1 )
replace R190 = . if (R190 <= -1 )
replace R191 = . if (R191 <= -1 )
replace R192 = . if (R192 <= -1 )
replace R193 = . if (R193 <= -1 )
replace R194 = . if (R194 <= -1 )
replace R195 = . if (R195 <= -1 )
replace R198A1 = . if (R198A1 <= -1 )
replace R198A2 = . if (R198A2 <= -1 )
replace R198A3 = . if (R198A3 <= -1 )
replace R198A4 = . if (R198A4 <= -1 )
replace R198A5 = . if (R198A5 <= -1 )
replace R200A1 = . if (R200A1 <= -1 )
replace R202A1 = . if (R202A1 <= -1 )
replace R200A2 = . if (R200A2 <= -1 )
replace R202A2 = . if (R202A2 <= -1 )
replace R200A3 = . if (R200A3 <= -1 )
replace R202A3 = . if (R202A3 <= -1 )
replace R200A4 = . if (R200A4 <= -1 )
replace R202A4 = . if (R202A4 <= -1 )
replace R200A5 = . if (R200A5 <= -1 )
replace R202A5 = . if (R202A5 <= -1 )
replace R203 = . if (R203 <= -1 )
replace R204M1 = . if (R204M1 <= -1 )
replace R204M2 = . if (R204M2 <= -1 )
replace R204M3 = . if (R204M3 <= -1 )
replace R204M4 = . if (R204M4 <= -1 )
replace R204M5 = . if (R204M5 <= -1 )
replace R204M6 = . if (R204M6 <= -1 )
replace R205 = . if (R205 <= -1 )
replace R206M1 = . if (R206M1 <= -1 )
replace R206M2 = . if (R206M2 <= -1 )
replace R206M3 = . if (R206M3 <= -1 )
replace R206M4 = . if (R206M4 <= -1 )
replace R206M5 = . if (R206M5 <= -1 )
replace R206M6 = . if (R206M6 <= -1 )
replace R207 = . if (R207 <= -1 )
replace R208M1 = . if (R208M1 <= -1 )
replace R208M2 = . if (R208M2 <= -1 )
replace R211 = . if (R211 <= -1 )
replace R212 = . if (R212 <= -1 )
replace R213 = . if (R213 <= -1 )
replace R214 = . if (R214 <= -1 )
replace R216 = . if (R216 <= -1 )
replace R218 = . if (R218 <= -1 )
replace R219 = . if (R219 <= -1 )
replace R220 = . if (R220 <= -1 )
replace R221 = . if (R221 == 5)
replace R221 = . if (R221 <= -1 )
replace R222 = . if (R222 <= -1 )
replace R223 = . if (R223 <= -1 )
replace R225 = . if (R225 <= -1 )
replace R226 = . if (R226 <= -1 )
replace R227 = . if (R227 <= -1 )
replace R228 = . if (R228 <= -1 )
replace R229 = . if (R229 <= -1 )
replace R231 = . if (R231 == 99)
replace R231 = . if (R231 <= -1 )
replace R232 = . if (R232 == 99)
replace R232 = . if (R232 <= -1 )
replace R233 = . if (R233 == 99)
replace R233 = . if (R233 <= -1 )
replace R234 = . if (R234 <= -1 )
replace R236 = . if (R236 <= -1 )
replace R237 = . if (R237 <= -1 )
replace R238 = . if (R238 <= -1 )
replace R239 = . if (R239 <= -1 )
replace R240 = . if (R240 <= -1 )
replace R241 = . if (R241 <= -1 )
replace R242 = . if (R242 <= -1 )
replace R244 = . if (R244 <= -1 )
replace R245 = . if (R245 <= -1 )
replace R246 = . if (R246 <= -1 )
replace R247 = . if (R247 <= -1 )
replace R248 = . if (R248 <= -1 )
replace R250 = . if (R250 <= -1 )
replace R251 = . if (R251 <= -1 )
replace R253 = . if (R253 <= -1 )
replace R255 = . if (R255 <= -1 )
replace R256 = . if (R256 <= -1 )
replace R258 = . if (R258 <= -1 )
replace R259 = . if (R259 == 999)
replace R259 = . if (R259 <= -1 )
replace R260 = . if (R260 == 7)
replace R260 = . if (R260 <= -1 )
replace R262 = . if (R262 == 5)
replace R262 = . if (R262 <= -1 )
replace R263 = . if (R263 <= -1 )
replace R264 = . if (R264 == 3)
replace R264 = . if (R264 <= -1 )
replace R270M1 = . if (R270M1 <= -1 )
replace R270M2 = . if (R270M2 <= -1 )
replace R270M3 = . if (R270M3 <= -1 )
replace R270M4 = . if (R270M4 <= -1 )
replace R271 = . if (R271 <= -1 )
replace R272M1 = . if (R272M1 <= -1 )
replace R272M2 = . if (R272M2 <= -1 )
replace R272M3 = . if (R272M3 <= -1 )
replace R273 = . if (R273 <= -1 )
replace R274 = . if (R274 <= -1 )
replace R275 = . if (R275 <= -1 )
replace R276 = . if (R276 <= -1 )
replace R277 = . if (R277 <= -1 )
replace R278 = . if (R278 <= -1 )
replace R279 = . if (R279 <= -1 )
replace R280 = . if (R280 <= -1 )
replace R281 = . if (R281 <= -1 )
replace R282 = . if (R282 <= -1 )
replace R287 = . if (R287 <= -1 )
replace R288 = . if (R288 <= -1 )
replace R289 = . if (R289 <= -1 )
replace R290 = . if (R290 <= -1 )
replace R291 = . if (R291 <= -1 )
replace R292 = . if (R292 <= -1 )
replace R293 = . if (R293 <= -1 )
replace R294 = . if (R294 <= -1 )
replace R295 = . if (R295 <= -1 )
replace R296 = . if (R296 == 3)
replace R296 = . if (R296 <= -1 )
replace R297 = . if (R297 <= -1 )
replace R298 = . if (R298 <= -1 )
replace R299 = . if (R299 <= -1 )
replace R300 = . if (R300 <= -1 )
replace R301 = . if (R301 <= -1 )
replace R302 = . if (R302 <= -1 )
replace R303 = . if (R303 <= -1 )
replace R304 = . if (R304 <= -1 )
replace R305 = . if (R305 <= -1 )
replace R306 = . if (R306 <= -1 )
replace R307 = . if (R307 <= -1 )
replace R308 = . if (R308 <= -1 )
replace R309 = . if (R309 <= -1 )
replace R310 = . if (R310 <= -1 )
replace R311 = . if (R311 <= -1 )
replace R313A1 = . if (R313A1 <= -1 )
replace R313A2 = . if (R313A2 <= -1 )
replace R313A3 = . if (R313A3 <= -1 )
replace R314 = . if (R314 <= -1 )
replace R322 = . if (R322 <= -1 )
replace R323 = . if (R323 <= -1 )
replace R324 = . if (R324 <= -1 )
replace R325 = . if (R325 <= -1 )
replace R326 = . if (R326 <= -1 )
replace R327 = . if (R327 <= -1 )
replace R328 = . if (R328 <= -1 )
replace R329 = . if (R329 <= -1 )
replace R330 = . if (R330 <= -1 )
replace R331 = . if (R331 <= -1 )
replace R332 = . if (R332 <= -1 )
replace R333 = . if (R333 <= -1 )
replace R334 = . if (R334 <= -1 )
replace R335 = . if (R335 <= -1 )
replace R336 = . if (R336 <= -1 )
replace R337 = . if (R337 <= -1 )
replace R338 = . if (R338 <= -1 )
replace R339 = . if (R339 <= -1 )
replace R340 = . if (R340 <= -1 )
replace R341 = . if (R341 <= -1 )
replace R344A2 = . if (R344A2 <= -1 )
replace R345A2 = . if (R345A2 <= -1 )
replace R344A3 = . if (R344A3 <= -1 )
replace R345A3 = . if (R345A3 <= -1 )
replace R345A5 = . if (R345A5 <= -1 )
replace R345A10 = . if (R345A10 <= -1 )
replace R344A11 = . if (R344A11 <= -1 )
replace R345A11 = . if (R345A11 <= -1 )
replace R344A12 = . if (R344A12 <= -1 )
replace R345A12 = . if (R345A12 <= -1 )
replace R344A15 = . if (R344A15 <= -1 )
replace R345A15 = . if (R345A15 <= -1 )
replace R345A16 = . if (R345A16 <= -1 )
replace R345A17 = . if (R345A17 <= -1 )
replace R344A18 = . if (R344A18 <= -1 )
replace R346 = . if (R346 <= -1 )
replace R348A1 = . if (R348A1 <= -1 )
replace R351A1 = . if (R351A1 <= -1 )
replace R348A2 = . if (R348A2 <= -1 )
replace R351A2 = . if (R351A2 <= -1 )
replace R348A3 = . if (R348A3 <= -1 )
replace R351A3 = . if (R351A3 <= -1 )
replace R348A4 = . if (R348A4 <= -1 )
replace R351A4 = . if (R351A4 <= -1 )
replace R348A5 = . if (R348A5 <= -1 )
replace R351A5 = . if (R351A5 <= -1 )
replace R348A6 = . if (R348A6 <= -1 )
replace R351A6 = . if (R351A6 <= -1 )
replace R348A7 = . if (R348A7 <= -1 )
replace R351A7 = . if (R351A7 <= -1 )
replace R348A8 = . if (R348A8 <= -1 )
replace R351A8 = . if (R351A8 <= -1 )
replace R348A9 = . if (R348A9 <= -1 )
replace R351A9 = . if (R351A9 <= -1 )
replace R348A10 = . if (R348A10 <= -1 )
replace R351A10 = . if (R351A10 <= -1 )
replace R348A11 = . if (R348A11 <= -1 )
replace R351A11 = . if (R351A11 <= -1 )
replace R348A12 = . if (R348A12 <= -1 )
replace R351A12 = . if (R351A12 <= -1 )
replace R348A13 = . if (R348A13 <= -1 )
replace R351A13 = . if (R351A13 <= -1 )
replace R348A14 = . if (R348A14 <= -1 )
replace R351A14 = . if (R351A14 <= -1 )
replace R348A15 = . if (R348A15 <= -1 )
replace R351A15 = . if (R351A15 <= -1 )
replace R348A16 = . if (R348A16 <= -1 )
replace R351A16 = . if (R351A16 <= -1 )
replace R348A17 = . if (R348A17 <= -1 )
replace R351A17 = . if (R351A17 <= -1 )
replace R348A18 = . if (R348A18 <= -1 )
replace R351A18 = . if (R351A18 <= -1 )
replace R348A19 = . if (R348A19 <= -1 )
replace R351A19 = . if (R351A19 <= -1 )
replace R348A20 = . if (R348A20 <= -1 )
replace R351A20 = . if (R351A20 <= -1 )
replace R348A21 = . if (R348A21 <= -1 )
replace R351A21 = . if (R351A21 <= -1 )
replace R352 = . if (R352 <= -1 )
replace R353 = . if (R353 <= -1 )
replace R354 = . if (R354 <= -1 )
replace R357 = . if (R357 <= -1 )
replace R358 = . if (R358 <= -1 )
replace R359 = . if (R359 <= -1 )
replace R360 = . if (R360 <= -1 )
replace R361 = . if (R361 == 3)
replace R361 = . if (R361 <= -1 )
replace R362 = . if (R362 == 3)
replace R362 = . if (R362 <= -1 )
replace R363 = . if (R363 <= -1 )
replace R364 = . if (R364 <= -1 )
replace R365 = . if (R365 <= -1 )
replace R366 = . if (R366 <= -1 )
replace R369 = . if (R369 == 6)
replace R369 = . if (R369 <= -1 )
replace R371 = . if (R371 <= -1 )
replace R372 = . if (R372 <= -1 )
replace R373 = . if (R373 <= -1 )
replace R375 = . if (R375 <= -1 )
replace R377 = . if (R377 <= -1 )
replace R378M1 = . if (R378M1 <= -1 )
replace R378M2 = . if (R378M2 <= -1 )
replace R378M3 = . if (R378M3 <= -1 )
replace R378M4 = . if (R378M4 <= -1 )
replace R378M5 = . if (R378M5 <= -1 )
replace R378M6 = . if (R378M6 <= -1 )
replace R378M7 = . if (R378M7 <= -1 )
replace R378M8 = . if (R378M8 <= -1 )
replace R378M9 = . if (R378M9 <= -1 )
replace R378M10 = . if (R378M10 <= -1 )
replace R378M11 = . if (R378M11 <= -1 )
replace R378M12 = . if (R378M12 <= -1 )
replace R378M13 = . if (R378M13 <= -1 )
replace R378M14 = . if (R378M14 <= -1 )
replace R378M15 = . if (R378M15 <= -1 )
replace R378M16 = . if (R378M16 <= -1 )
replace R378M17 = . if (R378M17 <= -1 )
replace R379 = . if (R379 <= -1 )
replace R380 = . if (R380 <= -1 )
replace R381 = . if (R381 <= -1 )
replace R384A1 = . if (R384A1 <= -1 )
replace R385A1 = . if (R385A1 <= -1 )
replace R388A1 = . if (R388A1 <= -1 )
replace R389A1 = . if (R389A1 <= -1 )
replace R389A2 = . if (R389A2 <= -1 )
replace R391 = . if (R391 <= -1 )
replace R392 = . if (R392 == 3)
replace R392 = . if (R392 <= -1 )
replace R393 = . if (R393 == 3)
replace R393 = . if (R393 <= -1 )
replace R397M1 = . if (R397M1 == 3)
replace R397M1 = . if (R397M1 <= -1 )
replace R397M2 = . if (R397M2 == 3)
replace R397M2 = . if (R397M2 <= -1 )
replace R397M3 = . if (R397M3 == 3)
replace R397M3 = . if (R397M3 <= -1 )
replace R397M4 = . if (R397M4 == 3)
replace R397M4 = . if (R397M4 <= -1 )
replace R397M5 = . if (R397M5 == 3)
replace R397M5 = . if (R397M5 <= -1 )
replace R397M6 = . if (R397M6 == 3)
replace R397M6 = . if (R397M6 <= -1 )
replace R397M7 = . if (R397M7 == 3)
replace R397M7 = . if (R397M7 <= -1 )
replace R397M8 = . if (R397M8 == 3)
replace R397M8 = . if (R397M8 <= -1 )
replace R397M9 = . if (R397M9 == 3)
replace R397M9 = . if (R397M9 <= -1 )
replace R397M10 = . if (R397M10 == 3)
replace R397M10 = . if (R397M10 <= -1 )
replace R397M11 = . if (R397M11 == 3)
replace R397M11 = . if (R397M11 <= -1 )
replace R399 = . if (R399 <= -1 )
replace R400 = . if (R400 <= -1 )
replace R401 = . if (R401 <= -1 )
replace R403 = . if (R403 <= -1 )
replace R407M2 = . if (R407M2 <= -1 )
replace R409 = . if (R409 <= -1 )
replace R411 = . if (R411 <= -1 )
replace R412 = . if (R412 <= -1 )
replace R413 = . if (R413 <= -1 )
replace R416A1 = . if (R416A1 <= -1 )
replace R416A2 = . if (R416A2 <= -1 )
replace R416A3 = . if (R416A3 <= -1 )
replace R416A4 = . if (R416A4 <= -1 )
replace R416A5 = . if (R416A5 <= -1 )
replace R416A6 = . if (R416A6 <= -1 )
replace R416A7 = . if (R416A7 <= -1 )
replace R419M1 = . if (R419M1 <= -1 )
replace R419M2 = . if (R419M2 <= -1 )
replace R420 = . if (R420 <= -1 )
replace R423 = . if (R423 <= -1 )
replace R427A1 = . if (R427A1 <= -1 )
replace R427A2 = . if (R427A2 <= -1 )
replace R427A3 = . if (R427A3 <= -1 )
replace R427A4 = . if (R427A4 <= -1 )
replace R427A5 = . if (R427A5 <= -1 )
replace R427A6 = . if (R427A6 <= -1 )
replace R427A7 = . if (R427A7 <= -1 )
replace R427A8 = . if (R427A8 <= -1 )
replace R427A9 = . if (R427A9 <= -1 )
replace R427A10 = . if (R427A10 <= -1 )
replace R428 = . if (R428 <= -1 )
replace R429 = . if (R429 <= -1 )
replace R431 = . if (R431 <= -1 )
replace R436A1 = . if (R436A1 <= -1 )
replace R437A1 = . if (R437A1 == 6)
replace R437A1 = . if (R437A1 <= -1 )
replace R436A2 = . if (R436A2 <= -1 )
replace R437A2 = . if (R437A2 == 6)
replace R437A2 = . if (R437A2 <= -1 )
replace R436A3 = . if (R436A3 <= -1 )
replace R437A3 = . if (R437A3 == 6)
replace R437A3 = . if (R437A3 <= -1 )
replace R436A4 = . if (R436A4 <= -1 )
replace R437A4 = . if (R437A4 == 6)
replace R437A4 = . if (R437A4 <= -1 )
replace R436A5 = . if (R436A5 <= -1 )
replace R437A5 = . if (R437A5 == 6)
replace R437A5 = . if (R437A5 <= -1 )
replace R439 = . if (R439 <= -1 )
replace R440 = . if (R440 <= -1 )
replace R441 = . if (R441 <= -1 )
replace R442 = . if (R442 <= -1 )
replace R443 = . if (R443 <= -1 )
replace R444 = . if (R444 <= -1 )
replace R445 = . if (R445 <= -1 )
replace R447 = . if (R447 <= -1 )
replace R448 = . if (R448 <= -1 )
replace R449 = . if (R449 <= -1 )
replace R450 = . if (R450 <= -1 )
replace R451 = . if (R451 <= -1 )
replace R452 = . if (R452 <= -1 )
replace R454A1 = . if (R454A1 <= -1 )
replace R456A1 = . if (R456A1 <= -1 )
replace R455A2 = . if (R455A2 <= -1 )
replace R456A2 = . if (R456A2 <= -1 )
replace R455A3 = . if (R455A3 <= -1 )
replace R456A3 = . if (R456A3 <= -1 )
replace R457 = . if (R457 <= -1 )
replace R458 = . if (R458 <= -1 )
replace R459M1 = . if (R459M1 <= -1 )
replace R459M2 = . if (R459M2 <= -1 )
replace R459M3 = . if (R459M3 <= -1 )
replace R459M4 = . if (R459M4 <= -1 )
replace R462M1 = . if (R462M1 <= -1 )
replace R462M4 = . if (R462M4 <= -1 )
replace R462M5 = . if (R462M5 <= -1 )
replace R463 = . if (R463 <= -1 )
replace R464 = . if (R464 <= -1 )
replace R465 = . if (R465 <= -1 )
replace R466 = . if (R466 <= -1 )
replace R467 = . if (R467 == 3)
replace R467 = . if (R467 <= -1 )
replace R468 = . if (R468 == 3)
replace R468 = . if (R468 <= -1 )
replace R469 = . if (R469 == 3)
replace R469 = . if (R469 <= -1 )
replace R470 = . if (R470 <= -1 )
replace R471 = . if (R471 <= -1 )
replace R472 = . if (R472 <= -1 )
replace R474 = . if (R474 <= -1 )
replace RTOTANS = . if (RTOTANS <= -1 )
replace RTOTREF = . if (RTOTREF <= -1 )
replace RTOTDK = . if (RTOTDK <= -1 )
replace AFDRUG1 = . if (AFDRUG1 <= -1 )
replace AFDRUG2 = . if (AFDRUG2 <= -1 )
replace QUEXSTAT = . if (QUEXSTAT <= -1 )
replace BCSTAT = . if (BCSTAT <= -1 )
replace URISTAT = . if (URISTAT <= -1 )
replace LOS = . if (LOS <= -1.00 )
replace LOSCENSR = . if (LOSCENSR <= -1 )
replace DURATTX = . if (DURATTX <= -1.00 )
replace DURAPTX = . if (DURAPTX <= -1 )
replace DURAPDP = . if (DURAPDP <= -1.00 )
replace TFSCOMP = . if (TFSCOMP <= -1 )
replace NRIQLTAR = . if (NRIQLTAR <= -1 )
replace NRIQDRUG = . if (NRIQDRUG <= -1 )
replace NPAQAR = . if (NPAQAR <= -1 )
replace FLDISP = . if (FLDISP <= -1 )
replace LABDISP = . if (LABDISP <= -1 )
replace CAN = . if (CAN <= -1 )
replace COC = . if (COC <= -1 )
replace PCP = . if (PCP <= -1 )
replace OPI = . if (OPI <= -1 )
replace AMP = . if (AMP <= -1 )
replace BEN = . if (BEN <= -1 )
replace MET = . if (MET <= -1 )
replace ALC = . if (ALC <= -1 )
replace RBEERVOL = . if (RBEERVOL <= -1 )
replace RWINEVOL = . if (RWINEVOL <= -1 )
replace RLIQUVOL = . if (RLIQUVOL <= -1 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

